@@ -23,17 +23,14 @@ import os
 import re
 import shlex
 import sys
-
+import warnings
 from enum import Enum
 
-from . import data_dir
-from . import output
-from . import test
-from . import safeloader
-from .references import reference_split
 from ..utils import stacktrace
-from .future.settings import settings as future_settings
+from . import data_dir, output, safeloader, test
 from .output import LOG_UI
+from .references import reference_split
+from .settings import settings
 
 
 class DiscoverMode(Enum):
@@ -70,7 +67,7 @@ class LoaderUnhandledReferenceError(LoaderError):
 
     def __str__(self):
         return ("Unable to resolve reference(s) '%s' with plugins(s) '%s', "
-                "try running 'avocado list -V %s' to see the details."
+                "try running 'avocado -V list %s' to see the details."
                 % ("', '" .join(self.unhandled_references),
                    "', '".join(self.plugins),
                    " ".join(self.unhandled_references)))
@@ -96,7 +93,7 @@ class TestLoaderProxy:
             raise InvalidLoaderPlugin("Object %s is not an instance of "
                                       "TestLoader" % plugin)
 
-    def load_plugins(self, args):
+    def load_plugins(self, config):
         def _good_test_types(plugin):
             """
             List all supported test types (excluding incorrect ones)
@@ -120,14 +117,18 @@ class TestLoaderProxy:
                                        ", ".join(_good_test_types(plugin)))
             return out.rstrip('\n')
 
-        subcommand = args.get('subcommand')
+        subcommand = config.get('subcommand')
         self.register_plugin(TapLoader)
         # Register external runner when --external-runner is used
-        external_runner = args.get("{}.external_runner".format(subcommand))
+        external_runner = config.get("{}.external_runner".format(subcommand))
         if external_runner:
             self.register_plugin(ExternalLoader)
             key = "{}.loaders".format(subcommand)
-            args[key] = ["external:{}".format(external_runner)]
+            if set(config[key]) != {'file', '@DEFAULT'}:
+                warnings.warn("The loaders and external-runner are incompatible."
+                              "The values in loaders will be ignored.",
+                              RuntimeWarning)
+            config[key] = ["external:{}".format(external_runner)]
         else:
             # Add (default) file loader if not already registered
             if FileLoader not in self.registered_plugins:
@@ -140,7 +141,7 @@ class TestLoaderProxy:
             supported_types.extend(_good_test_types(plugin))
 
         # Here is one of the few exceptions that has a hardcoded default
-        loaders = args.get("{}.loaders".format(subcommand)) or ['file',
+        loaders = config.get("{}.loaders".format(subcommand)) or ['file',
                                                                 '@DEFAULT']
         if "@DEFAULT" in loaders:  # Replace @DEFAULT with unused loaders
             idx = loaders.index("@DEFAULT")
@@ -163,7 +164,7 @@ class TestLoaderProxy:
             if len(loaders[i]) == 2:
                 extra_params['loader_options'] = loaders[i][1]
             plugin = self.registered_plugins[supported_loaders.index(name)]
-            self._initialized_plugins.append(plugin(args, extra_params))
+            self._initialized_plugins.append(plugin(config, extra_params))
 
     def _update_mappings(self):
         """
@@ -298,8 +299,6 @@ class TestLoaderProxy:
             test_parameters['modulePath'] = test_path
         if 'run.results_dir' in test_parameters:
             test_parameters['base_logdir'] = test_parameters.pop('run.results_dir')
-        elif 'nrun.results_dir' in test_parameters:
-            test_parameters['base_logdir'] = test_parameters.pop('nrun.results_dir')
         test_instance = test_class(**test_parameters)
 
         return test_instance
@@ -316,7 +315,7 @@ class TestLoader:
 
     name = None     # Human friendly name of the loader
 
-    def __init__(self, args, extra_params):  # pylint: disable=W0613
+    def __init__(self, config, extra_params):  # pylint: disable=W0613
         if "allowed_test_types" in extra_params:
             mapping = self.get_type_label_mapping()
             types = extra_params.pop("allowed_test_types")
@@ -341,7 +340,7 @@ class TestLoader:
             raise LoaderError("Loader '%s' doesn't handle extra params %s, "
                               "please adjust your plugin to take care of them."
                               % (self.name, extra_params))
-        self.args = args
+        self.config = config
 
     def get_extra_listing(self):
         pass
@@ -403,26 +402,26 @@ def add_loader_options(parser, section='run'):
                 "either @loader_name or TEST_TYPE. By default it tries all "
                 "available loaders according to priority set in "
                 "settings->plugins.loaders.")
-    future_settings.register_option(section=section,
-                                    key='loaders',
-                                    nargs='*',
-                                    key_type=list,
-                                    default=['file', '@DEFAULT'],
-                                    help_msg=help_msg,
-                                    parser=arggrp,
-                                    long_arg='--loaders')
+    settings.register_option(section=section,
+                             key='loaders',
+                             nargs='*',
+                             key_type=list,
+                             default=['file', '@DEFAULT'],
+                             help_msg=help_msg,
+                             parser=arggrp,
+                             long_arg='--loaders')
 
     help_msg = ("Path to an specific test runner that allows the use of its "
                 "own tests. This should be used for running tests that do not "
                 "conform to Avocado\'s SIMPLE test interface and can not run "
                 "standalone. Note: the use of --external-runner overwrites "
                 "the --loaders to 'external_runner'")
-    future_settings.register_option(section=section,
-                                    key='external_runner',
-                                    default=None,
-                                    help_msg=help_msg,
-                                    parser=arggrp,
-                                    long_arg='--external-runner')
+    settings.register_option(section=section,
+                             key='external_runner',
+                             default=None,
+                             help_msg=help_msg,
+                             parser=arggrp,
+                             long_arg='--external-runner')
 
     help_msg = ("Change directory before executing tests. This option may be "
                 "necessary because of requirements and/or limitations of the "
@@ -432,25 +431,25 @@ def add_loader_options(parser, section='run'):
                 "be run from the directory where those files are located, "
                 "use 'test' here and specify the test directory with the "
                 "option '--external-runner-testdir'.")
-    future_settings.register_option(section=section,
-                                    key='external_runner_chdir',
-                                    help_msg=help_msg,
-                                    default=None,
-                                    parser=arggrp,
-                                    choices=('runner', 'test'),
-                                    long_arg='--external-runner-chdir')
+    settings.register_option(section=section,
+                             key='external_runner_chdir',
+                             help_msg=help_msg,
+                             default=None,
+                             parser=arggrp,
+                             choices=('runner', 'test'),
+                             long_arg='--external-runner-chdir')
 
     help_msg = ("Where test files understood by the external test runner "
                 "are located in the filesystem. Obviously this assumes and "
                 "only applies to external test runners that run tests from "
                 "files")
-    future_settings.register_option(section=section,
-                                    key='external_runner_testdir',
-                                    metavar='DIRECTORY',
-                                    default=None,
-                                    help_msg=help_msg,
-                                    parser=arggrp,
-                                    long_arg='--external-runner-testdir')
+    settings.register_option(section=section,
+                             key='external_runner_testdir',
+                             metavar='DIRECTORY',
+                             default=None,
+                             help_msg=help_msg,
+                             parser=arggrp,
+                             long_arg='--external-runner-testdir')
 
 
 class NotATest:
@@ -468,9 +467,9 @@ class SimpleFileLoader(TestLoader):
     name = 'file'
     NOT_TEST_STR = ("Not a supported test")
 
-    def __init__(self, args, extra_params):
+    def __init__(self, config, extra_params):
         test_type = extra_params.pop('allowed_test_types', None)
-        super(SimpleFileLoader, self).__init__(args, extra_params)
+        super(SimpleFileLoader, self).__init__(config, extra_params)
         self.test_type = test_type
 
     @staticmethod
@@ -816,21 +815,21 @@ class ExternalLoader(TestLoader):
     """
     name = 'external'
 
-    def __init__(self, args, extra_params):
+    def __init__(self, config, extra_params):
         loader_options = extra_params.pop('loader_options', None)
-        super(ExternalLoader, self).__init__(args, extra_params)
+        super(ExternalLoader, self).__init__(config, extra_params)
         if loader_options == '?':
             raise LoaderError("File loader accepts an option to set the "
                               "external-runner executable.")
         self._external_runner = self._process_external_runner(
-            args, loader_options)
+            config, loader_options)
 
     @staticmethod
-    def _process_external_runner(args, runner):
+    def _process_external_runner(config, runner):
         """ Enables the external_runner when asked for """
-        subcommand = args.get('subcommand')
-        chdir = args.get("{}.external_runner_chdir".format(subcommand))
-        test_dir = args.get("{}.external_runner_testdir".format(subcommand))
+        subcommand = config.get('subcommand')
+        chdir = config.get("{}.external_runner_chdir".format(subcommand))
+        test_dir = config.get("{}.external_runner_testdir".format(subcommand))
 
         if runner:
             external_runner_and_args = shlex.split(runner)
