@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 
 import argparse
-import asyncio
 import base64
 import collections
 import inspect
@@ -16,6 +15,12 @@ import tempfile
 import time
 import unittest
 
+try:
+    import pkg_resources
+    PKG_RESOURCES_AVAILABLE = True
+except ImportError:
+    PKG_RESOURCES_AVAILABLE = False
+
 
 #: The amount of time (in seconds) between each internal status check
 RUNNER_RUN_CHECK_INTERVAL = 0.01
@@ -253,6 +258,26 @@ class Runnable:
         # future similar problems
         runners_registry[self.kind] = False
 
+    def pick_runner_class_from_entry_point(self):
+        """Selects a runner class from entry points based on kind.
+
+        This is related to the :data:`SpawnMethod.PYTHON_CLASS`. This
+        complements the :data:`RUNNERS_REGISTRY_PYTHON_CLASS` on systems
+        that have setuptools available.
+
+        :returns: a class that inherits from :class:`BaseRunner` or None
+        """
+        if not PKG_RESOURCES_AVAILABLE:
+            return
+        namespace = 'avocado.plugins.runnable.runner'
+        for ep in pkg_resources.iter_entry_points(namespace):
+            if ep.name == self.kind:
+                try:
+                    obj = ep.load()
+                    return obj
+                except ImportError:
+                    return
+
     def pick_runner_class(self, runners_registry=None):
         """Selects a runner class from the registry based on kind.
 
@@ -268,6 +293,8 @@ class Runnable:
             runners_registry = RUNNERS_REGISTRY_PYTHON_CLASS
 
         runner = runners_registry.get(self.kind, None)
+        if runner is None:
+            runner = self.pick_runner_class_from_entry_point()
         if runner is not None:
             return runner
         raise ValueError('Unsupported kind of runnable: %s' % self.kind)
@@ -295,7 +322,7 @@ class BaseRunner:
         :rtype: dict
         """
         status = {'status': status_type,
-                  'time': time.time()}
+                  'time': time.monotonic()}
 
         if isinstance(additional_info, dict):
             status.update(additional_info)
@@ -344,6 +371,8 @@ class ExecRunner(BaseRunner):
             current.update(self.runnable.kwargs)
             env = current
 
+        if env and 'PATH' not in env:
+            env['PATH'] = os.environ.get('PATH')
         process = subprocess.Popen(
             [self.runnable.uri] + list(self.runnable.args),
             stdin=subprocess.DEVNULL,
@@ -355,7 +384,7 @@ class ExecRunner(BaseRunner):
         most_current_execution_state_time = None
         while process.poll() is None:
             time.sleep(RUNNER_RUN_CHECK_INTERVAL)
-            now = time.time()
+            now = time.monotonic()
             if most_current_execution_state_time is not None:
                 next_execution_state_mark = (most_current_execution_state_time +
                                              RUNNER_RUN_STATUS_INTERVAL)
@@ -421,13 +450,32 @@ class PythonUnittestRunner(BaseRunner):
 
      * kwargs: not used
     """
+    @staticmethod
+    def _uri_to_unittest_name(uri):
+        if ':' in uri:
+            module, class_method = uri.rsplit(':', 1)
+        else:
+            module = uri
+            class_method = None
+        if module.endswith('.py'):
+            module = module[:-3]
+        if module.startswith(os.path.curdir):
+            module = module[1:]
+            if module.startswith(os.path.sep):
+                module = module[1:]
+        module = module.replace(os.path.sep, ".")
+        if class_method:
+            return '%s.%s' % (module, class_method)
+        return module
+
     @staticmethod
     def _run_unittest(uri, queue):
+        sys.path.insert(0, ".")
         stream = io.StringIO()
-        suite = unittest.TestLoader().loadTestsFromName(uri)
+        unittest_name = PythonUnittestRunner._uri_to_unittest_name(uri)
+        suite = unittest.TestLoader().loadTestsFromName(unittest_name)
         runner = unittest.TextTestRunner(stream=stream, verbosity=0)
         unittest_result = runner.run(suite)
-        time_end = time.time()
 
         if len(unittest_result.errors) > 0:
             result = 'error'
@@ -441,8 +489,7 @@ class PythonUnittestRunner(BaseRunner):
         stream.seek(0)
         output = {'status': 'finished',
                   'result': result,
-                  'output': stream.read(),
-                  'time': time_end}
+                  'output': stream.read()}
         stream.close()
         queue.put(output)
 
@@ -462,7 +509,7 @@ class PythonUnittestRunner(BaseRunner):
         most_current_execution_state_time = None
         while queue.empty():
             time.sleep(RUNNER_RUN_CHECK_INTERVAL)
-            now = time.time()
+            now = time.monotonic()
             if most_current_execution_state_time is not None:
                 next_execution_state_mark = (most_current_execution_state_time +
                                              RUNNER_RUN_STATUS_INTERVAL)
@@ -471,7 +518,9 @@ class PythonUnittestRunner(BaseRunner):
                 most_current_execution_state_time = now
                 yield self.prepare_status('running')
 
-        yield queue.get()
+        status = queue.get()
+        status['time'] = time.monotonic()
+        yield status
 
 
 RUNNERS_REGISTRY_PYTHON_CLASS['python-unittest'] = PythonUnittestRunner
@@ -533,22 +582,10 @@ class StatusEncoder(json.JSONEncoder):
         return json.JSONEncoder.default(self, o)
 
 
-def json_base64_decode(dct):
-    if '__base64_encoded__' in dct:
-        return base64.b64decode(dct['__base64_encoded__'])
-    return dct
-
-
 def json_dumps(data):
     return json.dumps(data, ensure_ascii=True, cls=StatusEncoder)
 
 
-def json_loads(data):
-    if isinstance(data, bytes):
-        data = data.decode()
-    return json.loads(data, object_hook=json_base64_decode)
-
-
 class TaskStatusService:
     """
     Implementation of interface that a task can use to post status updates
@@ -652,7 +689,7 @@ class Task:
         :returns: the arguments that can be used on an avocado-runner command
         :rtype: list
         """
-        args = ['-i', self.identifier]
+        args = ['-i', str(self.identifier)]
         args += self.runnable.get_command_args()
 
         for status_service in self.status_services:
@@ -674,96 +711,6 @@ class Task:
             yield status
 
 
-class StatusServer:
-
-    def __init__(self, uri, tasks_pending=None, verbose=False):
-        self.uri = uri
-        self.server_task = None
-        self.result = {}
-        if tasks_pending is None:
-            tasks_pending = []
-        self.tasks_pending = tasks_pending
-        self.verbose = verbose
-        self.wait_on_tasks_pending = len(self.tasks_pending) > 0
-
-    async def cb(self, reader, _):
-        while True:
-            if self.wait_on_tasks_pending:
-                if not self.tasks_pending:
-                    print('Status server: exiting due to all tasks finished')
-                    self.server_task.cancel()
-                    await self.server_task
-                    return True
-
-            message = await reader.readline()
-            message = message.strip()
-            if message == b'bye':
-                print('Status server: exiting due to user request')
-                self.server_task.cancel()
-                await self.server_task
-                return True
-
-            if not message:
-                return False
-
-            try:
-                data = json_loads(message)
-            except json.decoder.JSONDecodeError:
-                return False
-
-            if data.get('status') in ['started']:
-                self.handle_task_started(data)
-            elif data.get('status') in ['finished']:
-                self.handle_task_finished(data)
-
-    async def create_server_task(self):
-        host, port = self.uri.split(':')
-        port = int(port)
-        server = await asyncio.start_server(self.cb, host=host, port=port)
-        print("Status server started at:", self.uri)
-        await server.wait_closed()
-
-    def handle_task_started(self, data):
-        if self.verbose:
-            print("Task started: {}. Outputdir: {}".format(data['id'],
-                                                           data['output_dir']))
-
-    def handle_task_finished(self, data):
-        if 'result' not in data:
-            return
-
-        result = data['result']
-        task_id = data['id']
-
-        if self.wait_on_tasks_pending:
-            self.tasks_pending.remove(task_id)
-
-        if result not in self.result:
-            self.result[result] = []
-        self.result[result].append(task_id)
-
-        if self.verbose:
-            print('Task complete (%s): %s' % (result, task_id))
-            if result not in ('pass', 'skip'):
-                stdout = data.get('stdout', b'')
-                if stdout:
-                    print('Task %s stdout:\n%s\n' % (task_id, stdout))
-                stderr = data.get('stderr', b'')
-                if stderr:
-                    print('Task %s stderr:\n%s\n' % (task_id, stderr))
-                output = data.get('output', b'')
-                if output:
-                    print('Task %s output:\n%s\n' % (task_id, output))
-
-    def start(self):
-        loop = asyncio.get_event_loop()
-        self.server_task = loop.create_task(self.create_server_task())
-
-    async def wait(self):
-        while not self.server_task.done():
-            await asyncio.sleep(0.1)
-
-
 class BaseRunnerApp:
     '''
     Helper base class for common runner application behavior
@@ -974,22 +921,10 @@ class BaseRunnerApp:
         for status in task.run():
             self.echo(status)
 
-    def command_status_server(self, args):
-        """
-        Runs a status server
-
-        :param args: parsed command line arguments turned into a dictionary
-        :type args: dict
-        """
-        server = StatusServer(args.get('uri'))
-        server.start()
-        loop = asyncio.get_event_loop()
-        loop.run_until_complete(server.wait())
-
 
 class RunnerApp(BaseRunnerApp):
     PROG_NAME = 'avocado-runner'
-    PROG_DESCRIPTION = '*EXPERIMENTAL* N(ext) Runner'
+    PROG_DESCRIPTION = 'nrunner base application'
     RUNNABLE_KINDS_CAPABLE = RUNNERS_REGISTRY_PYTHON_CLASS
 
 
