@@ -2,9 +2,7 @@ import multiprocessing
 import tempfile
 import time
 
-from . import job
-from . import loader
-from . import nrunner
+from . import job, loader, nrunner
 from .test import TestID
 from .tree import TreeNode
 
@@ -55,6 +53,8 @@ class AvocadoInstrumentedTestRunner(nrunner.BaseRunner):
             if status in ['pass', 'fail', 'skip', 'error']:
                 state['result'] = status
                 state['status'] = 'finished'
+            else:
+                state['status'] = 'running'
 
         # This is a hack because the name is a TestID instance that can not
         # at this point be converted to JSON
@@ -68,12 +68,14 @@ class AvocadoInstrumentedTestRunner(nrunner.BaseRunner):
         queue = multiprocessing.SimpleQueue()
         process = multiprocessing.Process(target=self._run_avocado,
                                           args=(self.runnable, queue))
+
         process.start()
 
+        yield self.prepare_status('started')
         most_current_execution_state_time = None
         while queue.empty():
             time.sleep(nrunner.RUNNER_RUN_CHECK_INTERVAL)
-            now = time.time()
+            now = time.monotonic()
             if most_current_execution_state_time is not None:
                 next_execution_state_mark = (most_current_execution_state_time +
                                              nrunner.RUNNER_RUN_STATUS_INTERVAL)
@@ -82,12 +84,14 @@ class AvocadoInstrumentedTestRunner(nrunner.BaseRunner):
                 most_current_execution_state_time = now
                 yield self.prepare_status('running')
 
-        yield queue.get()
+        status = queue.get()
+        status['time'] = time.monotonic()
+        yield status
 
 
 class RunnerApp(nrunner.BaseRunnerApp):
     PROG_NAME = 'avocado-runner-avocado-instrumented'
-    PROG_DESCRIPTION = '*EXPERIMENTAL* N(ext) Runner for avocado-instrumented tests'
+    PROG_DESCRIPTION = 'nrunner application for avocado-instrumented tests'
     RUNNABLE_KINDS_CAPABLE = {
         'avocado-instrumented': AvocadoInstrumentedTestRunner
     }
