@@ -1,10 +1,10 @@
 import io
+import os
 import subprocess
 import time
 
 from . import nrunner
-from .tapparser import TapParser
-from .tapparser import TestResult
+from .tapparser import TapParser, TestResult
 
 
 class TAPRunner(nrunner.BaseRunner):
@@ -32,6 +32,8 @@ class TAPRunner(nrunner.BaseRunner):
     """
     def run(self):
         env = self.runnable.kwargs or None
+        if env and 'PATH' not in env:
+            env['PATH'] = os.environ.get('PATH')
         process = subprocess.Popen(
             [self.runnable.uri] + list(self.runnable.args),
             stdin=subprocess.DEVNULL,
@@ -43,8 +45,8 @@ class TAPRunner(nrunner.BaseRunner):
             time.sleep(nrunner.RUNNER_RUN_STATUS_INTERVAL)
             yield self.prepare_status('running')
 
-        stdout = io.TextIOWrapper(process.stdout)
-        parser = TapParser(stdout)
+        stdout = process.stdout.read()
+        parser = TapParser(io.StringIO(stdout.decode()))
         result = 'error'
         for event in parser.parse():
             if isinstance(event, TapParser.Bailout):
@@ -65,13 +67,15 @@ class TAPRunner(nrunner.BaseRunner):
 
         yield self.prepare_status('finished',
                                   {'result': result,
-                                   'returncode': process.returncode})
+                                   'returncode': process.returncode,
+                                   'stdout': stdout,
+                                   'stderr': process.stderr.read()})
 
 
 class RunnerApp(nrunner.BaseRunnerApp):
     PROG_NAME = 'avocado-runner-tap'
-    PROG_DESCRIPTION = ('*EXPERIMENTAL* N(ext) Runner for executable tests '
-                        'that produce TAP')
+    PROG_DESCRIPTION = ('nrunner application for executable tests that '
+                        'produce TAP')
     RUNNABLE_KINDS_CAPABLE = {'tap': TAPRunner}
 
 
