@@ -22,10 +22,10 @@ import re
 import sys
 import traceback
 
-from . import exit_codes
 from ..utils import path as utils_path
+from . import exit_codes
 from .settings import settings
-
+from .streams import BUILTIN_STREAMS
 
 #: Handle cases of logging exceptions which will lead to recursion error
 logging.raiseExceptions = False
@@ -35,16 +35,6 @@ LOG_UI = logging.getLogger("avocado.app")
 #: Pre-defined Avocado job/test logger
 LOG_JOB = logging.getLogger("avocado.test")
 
-#: Builtin special keywords to enable set of logging streams
-BUILTIN_STREAMS = {'app': 'application output',
-                   'test': 'test output',
-                   'debug': 'tracebacks and other debugging info',
-                   'remote': 'fabric/paramiko debug',
-                   'early':  'early logging of other streams, including test (very verbose)'}
-#: Groups of builtin streams
-BUILTIN_STREAM_SETS = {'all': 'all builtin streams',
-                       'none': 'disables regular output (leaving only errors enabled)'}
-
 
 class TermSupport:
 
@@ -85,10 +75,9 @@ class TermSupport:
         allowed_terms = ['linux', 'xterm', 'xterm-256color', 'vt100', 'screen',
                          'screen-256color', 'screen.xterm-256color']
         term = os.environ.get("TERM")
-        colored = settings.get_value('runner.output', 'colored',
-                                     key_type='bool', default=True)
-        force_color = settings.get_value('runner.output', 'color',
-                                         default="auto")
+        config = settings.as_dict()
+        colored = config.get('runner.output.colored')
+        force_color = config.get('runner.output.color')
         if force_color == "never":
             self.disable()
         elif force_color == "auto":
@@ -401,10 +390,38 @@ def early_start():
     logging.root.level = logging.DEBUG
 
 
+CONFIG = []
+
+
+def del_last_configuration():
+    if len(CONFIG) == 1:
+        return
+    configuration = CONFIG.pop()
+    for logger_name in configuration:
+        disable_log_handler(logger_name)
+    configuration = CONFIG[-1]
+    for logger_name, handlers in configuration.items():
+        logger = logging.getLogger(logger_name)
+        for handler in handlers:
+            logger.addHandler(handler)
+
+
 def reconfigure(args):
     """
     Adjust logging handlers accordingly to app args and re-log messages.
     """
+    def save_handler(logger_name, handler, configuration):
+        if logger_name not in configuration:
+            configuration[logger_name] = []
+        configuration[logger_name].append(handler)
+
+    # Delete last configuration
+    if len(CONFIG) != 0:
+        last_configuration = CONFIG[-1]
+        for logger_name in last_configuration:
+            disable_log_handler(logger_name)
+
+    configuration = {}
     # Reconfigure stream loggers
     enabled = args.get("core.show")
     if not isinstance(enabled, list):
@@ -435,6 +452,7 @@ def reconfigure(args):
         LOG_UI.addHandler(app_handler)
         LOG_UI.propagate = False
         LOG_UI.level = logging.DEBUG
+        save_handler(LOG_UI.name, app_handler, configuration)
     else:
         disable_log_handler(LOG_UI)
     app_err_handler = ProgressStreamHandler()
@@ -443,28 +461,25 @@ def reconfigure(args):
     app_err_handler.stream = STD_OUTPUT.stderr
     LOG_UI.addHandler(app_err_handler)
     LOG_UI.propagate = False
+    save_handler(LOG_UI.name, app_err_handler, configuration)
     if not os.environ.get("AVOCADO_LOG_EARLY"):
         LOG_JOB.getChild("stdout").propagate = False
         LOG_JOB.getChild("stderr").propagate = False
         if "early" in enabled:
-            add_log_handler("", logging.StreamHandler, STD_OUTPUT.stdout,
-                            logging.DEBUG)
-            add_log_handler(LOG_JOB, logging.StreamHandler,
-                            STD_OUTPUT.stdout, logging.DEBUG)
+            handler = add_log_handler("", logging.StreamHandler,
+                                      STD_OUTPUT.stdout, logging.DEBUG)
+            save_handler("", handler, configuration)
+            handler = add_log_handler(LOG_JOB, logging.StreamHandler,
+                                      STD_OUTPUT.stdout, logging.DEBUG)
+            save_handler(LOG_JOB.name, handler, configuration)
         else:
             disable_log_handler("")
-    if "remote" in enabled:
-        add_log_handler("avocado.fabric", stream=STD_OUTPUT.stdout,
-                        level=logging.DEBUG)
-        add_log_handler("paramiko", stream=STD_OUTPUT.stdout,
-                        level=logging.DEBUG)
-    else:
-        disable_log_handler("avocado.fabric")
-        disable_log_handler("paramiko")
     # Not enabled by env
     if not os.environ.get('AVOCADO_LOG_DEBUG'):
         if "debug" in enabled:
-            add_log_handler(LOG_UI.getChild("debug"), stream=STD_OUTPUT.stdout)
+            handler = add_log_handler(LOG_UI.getChild("debug"),
+                                      stream=STD_OUTPUT.stdout)
+            save_handler(LOG_UI.getChild("debug").name, handler, configuration)
         else:
             disable_log_handler(LOG_UI.getChild("debug"))
 
@@ -478,8 +493,9 @@ def reconfigure(args):
             level = (int(stream_level[1]) if stream_level[1].isdigit()
                      else logging.getLevelName(stream_level[1].upper()))
         try:
-            add_log_handler(name, logging.StreamHandler, STD_OUTPUT.stdout,
-                            level)
+            handler = add_log_handler(name, logging.StreamHandler,
+                                      STD_OUTPUT.stdout, level)
+            save_handler(name, handler, configuration)
         except ValueError as details:
             LOG_UI.error("Failed to set logger for --show %s:%s: %s.",
                          name, level, details)
@@ -493,6 +509,8 @@ def reconfigure(args):
     for record in MemStreamHandler.log:
         logging.getLogger(record.name).handle(record)
 
+    CONFIG.append(configuration)
+
 
 class FilterWarnAndMore(logging.Filter):
 
@@ -732,9 +750,8 @@ def log_plugin_failures(failures):
                      attribute `load_failures`
     """
     msg_fmt = 'Failed to load plugin from module "%s": %s :\n%s'
-    silenced = settings.get_value('plugins',
-                                  'skip_broken_plugin_notification',
-                                  list, [])
+    config = settings.as_dict()
+    silenced = config.get('plugins.skip_broken_plugin_notification')
     for failure in failures:
         if failure[0].module_name in silenced:
             continue
