@@ -15,10 +15,9 @@
 Human result UI
 """
 
-from avocado.core.output import LOG_UI
-from avocado.core.plugin_interfaces import ResultEvents
-from avocado.core.plugin_interfaces import JobPre, JobPost
 from avocado.core import output
+from avocado.core.output import LOG_UI
+from avocado.core.plugin_interfaces import JobPost, JobPre, ResultEvents
 
 
 class Human(ResultEvents):
@@ -34,13 +33,20 @@ class Human(ResultEvents):
         self.__throbber = output.Throbber()
         stdout_claimed_by = config.get('stdout_claimed_by', None)
         self.owns_stdout = not stdout_claimed_by
+        self.runner = config.get('run.test_runner')
 
     def pre_tests(self, job):
         if not self.owns_stdout:
             return
         LOG_UI.info("JOB ID     : %s", job.unique_id)
-        replay_source_job = job.config.get("replay_sourcejob", False)
-        if replay_source_job:
+        # TODO: this is part of the legacy implementation of the
+        # replay plugin and should be removed soon.
+        replay_enabled = replay_source_job = job.config.get("replay_sourcejob", False)
+        # The "avocado replay" plugin sets a different namespace
+        if not replay_source_job:
+            replay_enabled = job.config.get("job.replay.enabled")
+            replay_source_job = job.config.get("job.replay.source_job_id")
+        if replay_enabled and replay_source_job:
             LOG_UI.info("SRC JOB ID : %s", replay_source_job)
         LOG_UI.info("JOB LOG    : %s", job.logfile)
 
@@ -54,8 +60,11 @@ class Human(ResultEvents):
         else:
             name = "<unknown>"
             uid = '?'
-        LOG_UI.debug(' (%s/%s) %s:  ', uid, result.tests_total, name,
-                     extra={"skip_newline": True})
+        if self.runner == 'nrunner':
+            LOG_UI.debug(' (%s/%s) %s: STARTED', uid, result.tests_total, name)
+        else:
+            LOG_UI.debug(' (%s/%s) %s:  ', uid, result.tests_total, name,
+                         extra={"skip_newline": True})
 
     def test_progress(self, progress=False):
         if not self.owns_stdout:
@@ -87,7 +96,20 @@ class Human(ResultEvents):
         duration = (" (%.2f s)" % state.get('time_elapsed', -1)
                     if status != "SKIP"
                     else "")
-        msg = self.get_colored_status(status, state.get("fail_reason", None))
+        if self.runner == 'nrunner':
+            if "name" in state:
+                name = state["name"]
+                uid = name.str_uid
+                name = name.name + name.str_variant
+            else:
+                name = "<unknown>"
+                uid = '?'
+
+            msg = self.get_colored_status(status, state.get("fail_reason", None))
+            LOG_UI.debug(' (%s/%s) %s:  ', uid, result.tests_total, name,
+                         extra={"skip_newline": True})
+        else:
+            msg = self.get_colored_status(status, state.get("fail_reason", None))
         LOG_UI.debug(msg + duration)
 
     def post_tests(self, job):
