@@ -1,7 +1,4 @@
-#!/usr/bin/env python
-
 from avocado import Test
-from avocado import main
 
 
 class NastyException(Exception):
@@ -31,7 +28,3 @@ class FailTest(Test):
         Avocado should report this as TestError.
         """
         raise NastyException(None)  # str(Exception) fails!
-
-
-if __name__ == "__main__":
-    main()
