@@ -1,9 +1,6 @@
-#!/usr/bin/env python
-
 import os
 import time
 
-from avocado import main
 from avocado import Test
 
 
@@ -33,7 +30,3 @@ class SleepTenMin(Test):
                 time.sleep(length)
             elif method == 'shell':
                 os.system("sleep %s" % length)
-
-
-if __name__ == "__main__":
-    main()
