@@ -1,10 +1,10 @@
 import logging
 import os
-import pkg_resources
 import sys
 import tempfile
-import unittest.mock
+import unittest
 
+import pkg_resources
 
 #: The base directory for the avocado source tree
 BASEDIR = os.path.abspath(os.path.join(os.path.dirname(os.path.abspath(__file__)), '..'))
@@ -128,3 +128,20 @@ def skipOnLevelsInferiorThan(level):
     return unittest.skipIf(int(os.environ.get("AVOCADO_CHECK_LEVEL", 0)) < level,
                            "Skipping test that take a long time to run, are "
                            "resource intensive or time sensitve")
+
+
+def skipUnlessPathExists(path):
+    return unittest.skipUnless(os.path.exists(path),
+                               ('File or directory at path "%s" used in test is'
+                                ' not available in the system' % path))
+
+
+class TestCaseTmpDir(unittest.TestCase):
+
+    def setUp(self):
+        prefix = temp_dir_prefix(__name__, self, 'setUp')
+        self.tmpdir = tempfile.TemporaryDirectory(prefix=prefix)
+        os.chdir(BASEDIR)
+
+    def tearDown(self):
+        self.tmpdir.cleanup()
