@@ -1,13 +1,10 @@
 import os
-import tempfile
 import unittest
 
 from avocado.core import exit_codes
-from avocado.utils import process
-from avocado.utils import script
-
-from .. import AVOCADO, BASEDIR, temp_dir_prefix, skipOnLevelsInferiorThan
+from avocado.utils import process, script
 
+from .. import AVOCADO, TestCaseTmpDir, skipOnLevelsInferiorThan
 
 COMMANDS_TIMEOUT_CONF = """
 [sysinfo.collect]
@@ -18,15 +15,10 @@ commands = %s
 """
 
 
-class SysInfoTest(unittest.TestCase):
-
-    def setUp(self):
-        prefix = temp_dir_prefix(__name__, self, 'setUp')
-        self.tmpdir = tempfile.TemporaryDirectory(prefix=prefix)
+class SysInfoTest(TestCaseTmpDir):
 
     def test_sysinfo_enabled(self):
-        os.chdir(BASEDIR)
-        cmd_line = ('%s run --job-results-dir %s --sysinfo=on '
+        cmd_line = ('%s run --job-results-dir %s '
                     'passtest.py' % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -54,8 +46,7 @@ class SysInfoTest(unittest.TestCase):
             self.assertTrue(os.path.exists(sysinfo_subdir), msg)
 
     def test_sysinfo_disabled(self):
-        os.chdir(BASEDIR)
-        cmd_line = ('%s run --job-results-dir %s --sysinfo=off passtest.py'
+        cmd_line = ('%s run --job-results-dir %s --disable-sysinfo passtest.py'
                     % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -76,9 +67,8 @@ class SysInfoTest(unittest.TestCase):
         self.assertFalse(os.path.isdir(sysinfo_dir), msg)
 
     def test_sysinfo_html_output(self):
-        os.chdir(BASEDIR)
         html_output = "{}/output.html".format(self.tmpdir.name)
-        cmd_line = ('{} run --html {} --job-results-dir {} --sysinfo=on '
+        cmd_line = ('{} run --html {} --job-results-dir {} '
                     'passtest.py'.format(AVOCADO, html_output,
                                          self.tmpdir.name))
         result = process.run(cmd_line)
@@ -91,21 +81,18 @@ class SysInfoTest(unittest.TestCase):
 
         # Try to find some strings on HTML
         self.assertNotEqual(output.find('Filesystem'), -1)
-        self.assertNotEqual(output.find('root='), -1)
         self.assertNotEqual(output.find('MemAvailable'), -1)
-
-    def tearDown(self):
-        self.tmpdir.cleanup()
+        if not (os.getenv('TRAVIS') and os.getenv('TRAVIS_CPU_ARCH') == 'arm64'):
+            self.assertNotEqual(output.find('root='), -1)
 
     def run_sysinfo_interrupted(self, sleep, timeout, exp_duration):
-        os.chdir(BASEDIR)
         commands_path = os.path.join(self.tmpdir.name, "commands")
         script.make_script(commands_path, "sleep %s" % sleep)
         config_path = os.path.join(self.tmpdir.name, "config.conf")
         script.make_script(config_path,
                            COMMANDS_TIMEOUT_CONF % (timeout, commands_path))
         cmd_line = ("%s --show all --config %s run --job-results-dir %s "
-                    "--sysinfo=on passtest.py"
+                    "passtest.py"
                     % (AVOCADO, config_path, self.tmpdir.name))
         result = process.run(cmd_line)
         if timeout > 0:
